// JavaScript to write out ALE initial data 
// Date: 14 Oct 2010
// Version: 4.0 (Oasys 10)
// name: ALE Initial
// description: Write out initial data for ALE model
// NOTE: This requires Oasys D3PLOT 10 to run (select function)

ns = GetNumberOf(STATE);
nh = GetNumberOf(SOLID);
nn = GetNumberOf(NODE);

SetCurrentModel(1);
SetCurrentState(ns);

sel = Select(SOLID);

f = new File("ini_fac.key", File.WRITE);

f.Writeln("*INITIAL_VOLUME_FRACTION");
for(i=1; i<=nh; i++) // cycle through solid elements and write out volume fraction data
{
	if(IsSelected(SOLID,i)) // check if the solid was selected
	{
		s_id = GetLabel(SOLID, i);

		v_fra = GetData(SOX,SOLID,i,0,2) // SOX 1 = ALE MultiMaterial 1 Vol Faction
		v_fra = v_fra.toExponential(3);
	
		f.Writeln(s_id+","+v_fra);
	}
}

f.Writeln("*INITIAL_STRESS_SOLID");
for(i=1; i<=nh; i++) // cycle through solid elements and write out stress data
{
	if(IsSelected(SOLID,i)) // check if the solid was selected
	{
		s_id = GetLabel(SOLID, i);

		sxx = GetData(SXX,SOLID,i)
		sxx = sxx.toExponential(3);
	
		syy = GetData(SYY,SOLID,i)
		syy = syy.toExponential(3);
	
		szz = GetData(SZZ,SOLID,i)
		szz = szz.toExponential(3);

		f.Writeln(s_id+",1");
		f.Writeln(sxx+","+syy+","+szz+",0,0,0,0");
	}
}

f.Writeln("*INITIAL_VELOCITY_NODE");
for(i=1; i<=nn; i++) // cycle through nodes and write out velocity data
{
	flag = 0;

	ele = GetElemsAtNode(i, SOLID) // get the elements using the node

	for(j=0; j<ele.nn; j++) // cycle through the elements
	{
		eid = ele.list[j]
		if(IsSelected(SOLID,eid)) flag = 1; // check that an element on the node was selected
	} 

	if(flag == 1) // only process if the node is on a selected element
	{
		n_id = GetLabel(NODE, i);

		vx = GetData(VX,NODE,i)
		vx = vx.toExponential(3);

		vy = GetData(VY,NODE,i)
		vy = vy.toExponential(3);

		vz = GetData(VZ,NODE,i)
		vz = vz.toExponential(3);

		f.Writeln(n_id+","+vx+","+vy+","+vz);
	}
}

f.Close();
